# Copyright (C) 2010 Richard Lincoln
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA, USA


nsPrefix = "cimMotors"
nsURI = "http://iec.ch/TC57/2009/CIM-schema-cim14#Motors"

from CIM14.Dynamics.Motors.MechanicalLoad import MechanicalLoad
from CIM14.Dynamics.Motors.MotorSync import MotorSync
from CIM14.Dynamics.Motors.MechLoad1 import MechLoad1
from CIM14.Dynamics.Motors.MotorAsync import MotorAsync

class SynchronousMotorType(str):
    """Type of synchronous motor
    Values are: salientPole, roundRotor
    """
    pass
